summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KCmdLineArgs.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KCmdLineArgs.java')
-rw-r--r--kdejava/koala/org/kde/koala/KCmdLineArgs.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdejava/koala/org/kde/koala/KCmdLineArgs.java b/kdejava/koala/org/kde/koala/KCmdLineArgs.java
index 2b9bb2b7..3bba5437 100644
--- a/kdejava/koala/org/kde/koala/KCmdLineArgs.java
+++ b/kdejava/koala/org/kde/koala/KCmdLineArgs.java
@@ -28,7 +28,7 @@ import java.util.ArrayList;
KUniqueApplication app;
....
// Handle our own options/arguments
// A KApplication will usually do this in main but this is not
// necessary.
// A KUniqueApplication might want to handle it in newInstance().
KCmdLineArgs args = KCmdLineArgs.parsedArgs();
@@ -249,7 +249,7 @@ public class KCmdLineArgs implements QtSupport {
@param _description A short description of what your application is about.
@param _version A version.
@param noKApp Set this true to not add commandline options for
- TQApplication / KApplication
+ TQApplication / TDEApplication
@short Initialize class.
*/
public static native void init(String[] _argv, String _appname, String programName, String _description, String _version, boolean noKApp);
@@ -262,7 +262,7 @@ public class KCmdLineArgs implements QtSupport {
@param _argv As passed to <code>main</code>(...).
@param about A KAboutData object describing your program.
@param noKApp Set this true to not add commandline options for
- TQApplication / KApplication
+ TQApplication / TDEApplication
@short Initialize class.
*/
public static native void init(String[] _argv, KAboutData about, boolean noKApp);
@@ -445,8 +445,8 @@ public class KCmdLineArgs implements QtSupport {
public static native void setCwd(String cwd);
/**
Reset all option definitions, i.e. cancel all addCmdLineOptions calls.
- Note that KApplication's options are removed too, you might want to
- call KApplication.addCmdLineOptions if you want them back.
+ Note that TDEApplication's options are removed too, you might want to
+ call TDEApplication.addCmdLineOptions if you want them back.
You usually don't want to call this method.
@short Reset all option definitions, i.
*/
@@ -28,7 +28,7 @@ import java.util.ArrayList;
....
// Handle our own options/arguments
- // A KApplication will usually do this in main but this is not
+ // A TDEApplication will usually do this in main but this is not
// necessary.
// A KUniqueApplication might want to handle it in newInstance().